==> 0.1.1.tar.gz: lib/src/objects/Gallery.dart <==
import 'Album.dart';
import '../util/HttpWrapper.dart';
import 'Comment.dart';
import 'dart:async';

/// Imagur's gallery, can be gallery or subreddit gallery.
class Gallery extends Album {
  /// Upvotes for the image
  int ups;

  /// Number of downvotes for the image
  int downs;

  /// Upvotes minus downvotes
  int points;

  /// Imgur popularity score
  int score;

  /// if it's an album or not
  bool is_album;

  /// The current user's vote on the album. null if not signed in or if the user hasn't voted on it.
  String vote;

  /// Number of comments on the gallery album.
  int comment_count;

  /// Topic of the gallery album.
  String topic;

  /// Topic ID of the gallery album.
  int topic_id;

  /// Indicates if the album is in the most viral gallery or not
  bool in_most_viral;

  HttpWrapper _http;

  /// Creates new instance of Gallery
  Gallery(Map<String, dynamic> raw, this._http) : super(raw, _http) {
    ups = raw['ups'];
    downs = raw['downs'];
    points = raw['points'];
    score = raw['score'];
    is_album = raw['is_album'];
    vote = raw['vote'];
    comment_count = raw['comment_count'];
    topic = raw['topic'];
    topic_id = raw['topic_id'];
    in_most_viral = raw['in_most_viral'];
  }

  /// Returns list of comments attached to this Gallery
  Future<List<Comment>> getComments({String commentSort: "best"}) async {
    var res = await _http.createRequest("GET", "/gallery/${this.id}/comments/$commentSort");

    var tmp = new List();
    res.response['data'].forEach((Map<String, dynamic> o) {
      tmp.add(new Comment(o));
    });

    return tmp;
  }
}

==> 0.2.0.tar.gz: lib/src/objects/Gallery.dart <==
import 'Album.dart';
import '../util/HttpWrapper.dart';
import 'Comment.dart';
import 'dart:async';

/// Imagur's gallery, can be gallery or subreddit gallery.
class Gallery extends Album {
  /// Upvotes for the image
  int ups;

  /// Number of downvotes for the image
  int downs;

  /// Upvotes minus downvotes
  int points;

  /// Imgur popularity score
  int score;

  /// if it's an album or not
  bool is_album;

  /// The current user's vote on the album. null if not signed in or if the user hasn't voted on it.
  String vote;

  /// Number of comments on the gallery album.
  int comment_count;

  /// Topic of the gallery album.
  String topic;

  /// Topic ID of the gallery album.
  int topic_id;

  /// Indicates if the album is in the most viral gallery or not
  bool in_most_viral;

  HttpWrapper _http;

  /// Creates new instance of Gallery
  Gallery(Map<String, dynamic> raw, this._http) : super(raw, _http) {
    ups = raw['ups'];
    downs = raw['downs'];
    points = raw['points'];
    score = raw['score'];
    is_album = raw['is_album'];
    vote = raw['vote'];
    comment_count = raw['comment_count'];
    topic = raw['topic'];
    topic_id = raw['topic_id'];
    in_most_viral = raw['in_most_viral'];
  }

  /// Returns list of comments attached to this Gallery
  Future<List<Comment>> getComments({String commentSort: "best"}) async {
    var res = await _http.createRequest(
        "GET", "/gallery/${this.id}/comments/$commentSort");

    var tmp = new List<Comment>();
    res.response['data'].forEach((o) {
      tmp.add(new Comment(o));
    });

    return tmp;
  }
}
